# Copyright (c) 2019 Monolix
# 
# This software is released under the MIT License.
# https://opensource.org/licenses/MIT

from requests import get
import json

class DMOTD(object):
    def __init__(self, endpoint):
        self.endpoint = endpoint
    
    def raw(self):
        response = get(self.endpoint + "/raw")
        return response.text
    
    def json(self):
        response = get(self.endpoint + "/json")
        return response.json()



# Copyright (c) 2019 Monolix
# 
# This software is released under the MIT License.
# https://opensource.org/licenses/MIT

from flask import Flask, abort, jsonify, \
    Response
from logging import getLogger, ERROR

class DMOTD(Flask):
    def __init__(self, path="/etc/motd"):
        super().__init__("dmotd_daemon")

        self.dmotd_path = path

        log = getLogger('werkzeug')
        log.disabled = True
        
        self.dmotd_routes()
    
    def dmotd_routes(self):
        @self.route("/raw", methods=["GET"])
        def raw():
            try:
                with open(self.dmotd_path, "r") as f:
                    contents = f.read()
            except FileNotFoundError:
                return Response("Error: not found.", mimetype="text/plain")

            return Response(contents, mimetype="text/plain")

        @self.route("/json", methods=["GET"])
        def json():
            try:
                with open(self.dmotd_path, "r") as f:
                    contents = f.read()
            except FileNotFoundError:
                return jsonify({
                    "ok": False,
                    "error-code": 404,
                    "error-desc": "Not Found."
                })

            return jsonify({
                "ok": True,
                "lines": contents
            })



# Copyright (c) 2019 emanuele
# 
# This software is released under the MIT License.
# https://opensource.org/licenses/MIT

from setuptools import setup

def get_file_conts(file):
    with open(file, "r") as f:
        contents = f.read()
    
    return contents

setup(
    name="dmotd",
    version="0.0.1",
    description="Dynamic Message Of The Day.",
    long_description=get_file_conts("README.md"),
    long_description_content_type="text/markdown",
    url="http://github.com/monolix/dmotd",
    author="Monolix",
    author_email="monolix.team@gmail.com",
    license="MIT",
    packages=["dmotd"],
    install_requires=get_file_conts("requirements.txt").split("\n"),
    zip_safe=False
)